function PublishOutput = GaitCycle(PublishInput)
% Publishing Methods are .m functions that look at result files and produce new result files or publication figures
% PublishInput
%     .ResultFiles - cell array of file names passed to the method
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .PathSep - path separator '/' in mac/linux and '\' in windows
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader
% PublishOutput - not currently used
%

BaseDirectory = cd;

try

  set(PublishInput.ProgramStatusIndicator,'string','GaitCycle: Running...','foregroundcolor','g');drawnow;

%----------- Your code here !!! ---------------

for i = 1:10
    try
        close(i);
    end
end

figure(1);
set(gcf,'color','w');

Data = load(PublishInput.ResultFiles{1});

NumTimePoints = size(Data,1);

plothandle = plot(Data(1,1),Data(1,2),'linewidth',3);
hold on
xlim([0 110]);
ylim([0 12]);
xlabel('Percent Gait Cycle','fontsize',14);
ylabel('Ground Reaction Force','fontsize',14);
set(gca,'fontsize',14);
box off

for i = 1:NumTimePoints
   set(plothandle,'xdata',Data(1:i,1),'ydata',Data(1:i,2));
   drawnow;
   frame{i} = getframe(1);   
end

[savefile,savepath] = uiputfile('*.gif','Where do you want to save your animation?');

Frames2AnimatedGif = EnableHelperFunction([],{'Graphics';'Frames2AnimatedGif.m'});
Frames2AnimatedGif([savepath PublishInput.PathSep savefile],0.1*[0:length(frame)-1],frame,3,inf);

catch err
  set(PublishInput.ProgramStatusIndicator,'string','GaitCycle had an error. See Matlab window for details.','foregroundcolor','r');drawnow;
  cd(BaseDirectory);
  rethrow(err);
end

PublishOutput = 1;
