function PublishOutput = Example1_BasicFigure(PublishInput)
% Publishing Methods are .m functions that look at result files and produce new result files or publication figures
% PublishInput
%     .ResultFiles - cell array of file names passed to the method
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .PathSep - path separator '/' in mac/linux and '\' in windows
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader
% PublishOutput - not currently used
%

BaseDirectory = cd;

try

  set(PublishInput.ProgramStatusIndicator,'string','Example1_BasicFigure: Running...','foregroundcolor','g');drawnow;

  for i = 1:10
      try
          close(i);
      end
  end
  
%----------- Your code here !!! ---------------

% Enable relevant helper functions
NPS = EnableHelperFunction([],{'FigureProduction';'NewPresentationSlide.m'});
NPF = EnableHelperFunction([],{'FigureProduction';'NewPaperFigure.m'});
barweb = EnableHelperFunction([],{'Graphics';'barweb.m'});

% load the data from the excel file - PublishInput.ResultFiles{1} refers to the complete file name of the first selected file in the list 
[Data,Header] = xlsread(PublishInput.ResultFiles{1});

% let's run an ANOVA on our data to see what's significant
Outcome = Data(:,4);
Group = Data(:,2);
TimePoint = Data(:,3);
[P,T,STATS] = anovan(Outcome,[Group TimePoint],'model','interaction','varnames',{'PatientGroup';'TimePoint'});
[COMPARISON,MEANS,H,GNAMES] = multcompare(STATS,'ctype','bonferroni','dim',[1 2]);

h = msgbox('The program will now pause for you to inspect the ANOVA results. Click okay, and then press enter when you want to continue');
waitfor(h);
pause;
close(H);

% put the results in a matrix for bar graph (read help on bar). rows will
% correspond to time points, columns to patient group. M will be mean and E
% will be standard error
M = [MEANS(1,1) MEANS(2,1)
    MEANS(3,1) MEANS(4,1)];
E = [MEANS(1,2) MEANS(2,2)
    MEANS(3,2) MEANS(4,2)];

% create paper figure
hPaper = NPF('Margin',[0.5 0.5]);
haxes = axes('position',[0.5233 0.7 0.4533 0.2781]);

% let's make the paper figure active and work on it
figure(hPaper);
axes(haxes);
barweb(M, -E, +E, [], {'Pre-treatment';'Post-treatment'}, [], 'Time Point', 'Outcome Measure', jet, [], {'Patient Group 1';'Patient Group 2'},haxes);

% let's make the presentation slide active and work on it
hSlide = NPS('color','k');
haxes2 = axes('position',[0.1022 0.1597 0.7976 0.7316]);
Handles = barweb(M, -E, +E, [], {'Pre-treatment';'Post-treatment'}, [], 'Time Point', 'Outcome Measure', [], [], {'Patient Group 1';'Patient Group 2'},haxes2);

% set a whole bunch of things to the right color and size
set(hSlide,'color','k');
set(haxes2,'color','k','ycolor','w','xcolor','w','fontsize',14);
set(Handles.errorbar,'color','w');
set(Handles.xlabel,'color','w','fontsize',24);
set(Handles.ylabel,'color','w','fontsize',24);
set(Handles.legend,'TextColor','w','fontsize',16);

% make sure the colors don't get flipped in pdf
set(hSlide, 'InvertHardCopy', 'off');

% make some changes to both plots to indicate significance
set(haxes,'ylim',[-0.5 3]);
set(haxes2,'ylim',[-0.5 3]);

axes(haxes);
x1 = get(Handles.errorbar(1),'xdata');
x2 = get(Handles.errorbar(2),'xdata');
line([x1(2) x2(2)],[2.7 2.7],'color','k');
text((x1(2)+x2(2))/2,2.8,'*','horizontalalignment','center','fontsize',14);

axes(haxes2);
x1 = get(Handles.errorbar(1),'xdata');
x2 = get(Handles.errorbar(2),'xdata');
line([x1(2) x2(2)],[2.7 2.7],'color','w');
text((x1(2)+x2(2))/2,2.8,'*','horizontalalignment','center','fontsize',14,'color','w');

catch err
  set(PublishInput.ProgramStatusIndicator,'string','Example1_BasicFigure had an error. See Matlab window for details.','foregroundcolor','r');drawnow;
  cd(BaseDirectory);
  rethrow(err);
end

PublishOutput = 1;
